@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,26 +15,23 @@
  * @category     Zend
  * @package      Zend_Gdata_YouTube
  * @subpackage   UnitTests
- * @copyright    Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com);
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license      http://framework.zend.com/license/new-bsd     New BSD License
- * @version      $Id: VideoEntryTest.php 9361 2008-05-05 14:55:29Z jhartmann $
+ * @version      $Id$
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/Gdata/YouTube/VideoEntry.php';
 require_once 'Zend/Gdata/YouTube/Extension/State.php';
 require_once 'Zend/Gdata/YouTube.php';
 
 /**
- * @category     Zend
- * @package      Zend_Gdata_YouTube
- * @subpackage   UnitTests
- * @copyright    Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com);
- * @license      http://framework.zend.com/license/new-bsd     New BSD License
+ * @category   Zend
+ * @package    Zend_Gdata_YouTube
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Gdata
+ * @group      Zend_Gdata_YouTube
  */
 class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
 {
@@ -47,9 +43,12 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->privateEntryText = file_get_contents(
                 'Zend/Gdata/YouTube/_files/VideoEntryDataSamplePrivate.xml',
                 true);
+        $this->v2EntryText = file_get_contents(
+                'Zend/Gdata/YouTube/_files/VideoEntryDataSampleV2.xml',
+                true);
         $this->entry = new Zend_Gdata_YouTube_VideoEntry();
     }
-    
+
     private function createRandomString() {
         $randomString = '';
         for ($x = 0; $x < 10; $x++) {
@@ -143,6 +142,7 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('http://gdata.youtube.com/feeds/videos/UMFI1hdm96E/comments', $videoEntry->comments->feedLink->href);
 
         $this->assertEquals('37.398529052734375 -122.0635986328125', $videoEntry->where->point->pos->text);
+        $this->assertEquals('2008-09-25', $videoEntry->getVideoRecorded());
     }
 
     private function verifyAllPrivateSamplePropertiesAreCorrect ($videoEntry) {
@@ -230,6 +230,104 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('http://gdata.youtube.com/feeds/videos/UMFI1hdm96E/comments', $videoEntry->comments->feedLink->href);
 
         $this->assertEquals('37.398529052734375 -122.0635986328125', $videoEntry->where->point->pos->text);
+        $this->assertEquals('2008-09-25', $videoEntry->getVideoRecorded());
+    }
+
+    public function verifyAllV2SamplePropertiesAreCorrect($videoEntry) {
+         $this->assertEquals('tag:youtube.com,2008:video:UMFI1hdm96E',
+            $videoEntry->id->text);
+        $this->assertEquals('UMFI1hdm96E', $videoEntry->getVideoId());
+        $this->assertEquals('2008-12-08T04:04:33.000Z', $videoEntry->updated->text);
+
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[0]->scheme);
+        $this->assertEquals('cover', $videoEntry->category[0]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[1]->scheme);
+        $this->assertEquals('acoustic', $videoEntry->category[1]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[2]->scheme);
+        $this->assertEquals('gnarls', $videoEntry->category[2]->term);
+        $this->assertEquals('http://schemas.google.com/g/2005#kind', $videoEntry->category[3]->scheme);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007#video', $videoEntry->category[3]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[4]->scheme);
+        $this->assertEquals('barkley', $videoEntry->category[4]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[5]->scheme);
+        $this->assertEquals('music', $videoEntry->category[5]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/keywords.cat', $videoEntry->category[6]->scheme);
+        $this->assertEquals('singing', $videoEntry->category[6]->term);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/categories.cat', $videoEntry->category[7]->scheme);
+        $this->assertEquals('Music', $videoEntry->category[7]->term);
+
+        $this->assertEquals('text', $videoEntry->title->type);
+        $this->assertEquals('"Crazy (Gnarles Barkley)" - Acoustic Cover', $videoEntry->title->text);;
+        $this->assertEquals('application/x-shockwave-flash', $videoEntry->content->type);
+        $this->assertEquals('self', $videoEntry->getLink('self')->rel);
+        $this->assertEquals('application/atom+xml', $videoEntry->getLink('self')->type);
+        $this->assertEquals('http://gdata.youtube.com/feeds/api/videos/UMFI1hdm96E?v=2', $videoEntry->getLink('self')->href);
+        $this->assertEquals('text/html', $videoEntry->getLink('alternate')->type);
+        $this->assertEquals('http://www.youtube.com/watch?v=UMFI1hdm96E', $videoEntry->getLink('alternate')->href);
+        $this->assertEquals('application/atom+xml', $videoEntry->getLink('http://gdata.youtube.com/schemas/2007#video.responses')->type);
+        $this->assertEquals('http://gdata.youtube.com/feeds/api/videos/UMFI1hdm96E/responses?v=2', $videoEntry->getLink('http://gdata.youtube.com/schemas/2007#video.responses')->href);
+        $this->assertEquals('application/atom+xml', $videoEntry->getLink('http://gdata.youtube.com/schemas/2007#video.related')->type);
+        $this->assertEquals('http://gdata.youtube.com/feeds/api/videos/UMFI1hdm96E/related?v=2', $videoEntry->getLink('http://gdata.youtube.com/schemas/2007#video.related')->href);
+        $this->assertEquals('davidchoimusic', $videoEntry->author[0]->name->text);
+        $this->assertEquals('http://gdata.youtube.com/feeds/api/users/davidchoimusic', $videoEntry->author[0]->uri->text);
+
+        $mediaGroup = $videoEntry->mediaGroup;
+
+        $this->assertEquals('UMFI1hdm96E', $mediaGroup->getVideoId()->text);
+        $this->assertEquals('plain', $mediaGroup->title->type);
+        $this->assertEquals('"Crazy (Gnarles Barkley)" - Acoustic Cover', $mediaGroup->title->text);
+        $this->assertEquals('plain', $mediaGroup->description->type);
+        $this->assertEquals('Gnarles Barkley acoustic cover http://www.myspace.com/davidchoimusic', $mediaGroup->description->text);
+        $this->assertEquals('acoustic, barkley, cover, gnarls, music, singing', $mediaGroup->keywords->text);
+        $this->assertEquals(255, $mediaGroup->duration->seconds);
+
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/developertags.cat', $mediaGroup->category[0]->scheme);
+        $this->assertEquals('DeveloperTag1', $mediaGroup->category[0]->text);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007/categories.cat', $mediaGroup->category[1]->scheme);
+        $this->assertEquals('Music', $mediaGroup->category[1]->text);
+        $this->assertEquals('video', $mediaGroup->content[0]->medium);
+        $this->assertEquals('http://www.youtube.com/v/UMFI1hdm96E&f=gdata_videos', $mediaGroup->content[0]->url);
+        $this->assertEquals('application/x-shockwave-flash', $mediaGroup->content[0]->type);
+        $this->assertEquals('true', $mediaGroup->content[0]->isDefault);
+        $this->assertEquals('full', $mediaGroup->content[0]->expression);
+        $this->assertEquals(255, $mediaGroup->content[0]->duration);
+        $this->assertEquals(5, $mediaGroup->content[0]->format);
+        $this->assertEquals('http://www.youtube.com/watch?v=UMFI1hdm96E', $mediaGroup->player[0]->url);
+
+        $this->assertEquals('HK,TW', $mediaGroup->getMediaRating()->getCountry());
+        $this->assertEquals(1, $mediaGroup->getMediaRating()->text);
+        $this->assertEquals('http://gdata.youtube.com/schemas/2007#mediarating',
+            $mediaGroup->getMediaRating()->getScheme());
+
+        $this->assertEquals('http://i.ytimg.com/vi/UMFI1hdm96E/2.jpg', $mediaGroup->thumbnail[0]->url);
+        $this->assertEquals(97, $mediaGroup->thumbnail[0]->height);
+        $this->assertEquals(130, $mediaGroup->thumbnail[0]->width);
+        $this->assertEquals('00:02:07.500', $mediaGroup->thumbnail[0]->time);
+        $this->assertEquals('http://i.ytimg.com/vi/UMFI1hdm96E/1.jpg', $mediaGroup->thumbnail[1]->url);
+        $this->assertEquals(97, $mediaGroup->thumbnail[1]->height);
+        $this->assertEquals(130, $mediaGroup->thumbnail[1]->width);
+        $this->assertEquals('00:01:03.750', $mediaGroup->thumbnail[1]->time);
+        $this->assertEquals('http://i.ytimg.com/vi/UMFI1hdm96E/3.jpg', $mediaGroup->thumbnail[2]->url);
+        $this->assertEquals(97, $mediaGroup->thumbnail[2]->height);
+        $this->assertEquals(130, $mediaGroup->thumbnail[2]->width);
+        $this->assertEquals('00:03:11.250', $mediaGroup->thumbnail[2]->time);
+        $this->assertEquals('http://i.ytimg.com/vi/UMFI1hdm96E/0.jpg', $mediaGroup->thumbnail[3]->url);
+        $this->assertEquals(240, $mediaGroup->thumbnail[3]->height);
+        $this->assertEquals(320, $mediaGroup->thumbnail[3]->width);
+        $this->assertEquals('00:02:07.500', $mediaGroup->thumbnail[3]->time);
+
+        $this->assertEquals(267971, $videoEntry->statistics->viewCount);
+        $this->assertEquals(1, $videoEntry->rating->min);
+        $this->assertEquals(5, $videoEntry->rating->max);
+        $this->assertEquals(2062, $videoEntry->rating->numRaters);
+        $this->assertEquals(4.74, $videoEntry->rating->average);
+        $this->assertEquals('http://gdata.youtube.com/feeds/api/videos/UMFI1hdm96E/comments?v=2', $videoEntry->comments->feedLink->href);
+
+        $this->assertEquals('37.398529052734375 -122.0635986328125', $videoEntry->where->point->pos->text);
+        $this->assertEquals('2008-09-25', $videoEntry->getVideoRecorded());
+
+
+
     }
 
     public function testGetVideoId() {
@@ -240,15 +338,68 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('ABCDEFG12AB', $videoEntry->getVideoId());
     }
 
-    /**
-     * @expectedException Zend_Gdata_App_Exception
-     */
+    public function testGetVideoIdV2() {
+        $v2VideoEntry = new Zend_Gdata_YouTube_VideoEntry();
+        $v2VideoEntry->setMajorProtocolVersion(2);
+
+        $v2MediaGroup = new Zend_Gdata_YouTube_Extension_MediaGroup();
+        $v2MediaGroup->setVideoId(
+            new Zend_Gdata_YouTube_Extension_VideoId('UMFI1hdm96E'));
+
+        $v2VideoEntry->setMediaGroup($v2MediaGroup);
+
+        $this->assertEquals('UMFI1hdm96E', $v2VideoEntry->getVideoId());
+    }
+
     public function testGetVideoIdException() {
+
+        $exceptionCaught = false;
         $videoEntry = new Zend_Gdata_YouTube_VideoEntry();
 
-        // assert invalid ID
+        // use invalid ID
         $videoEntry->id = new Zend_Gdata_App_Extension_Id('adfadfasf');
-        $this->assertEquals('adfadfasf', $videoEntry->getVideoId());
+
+        try {
+            $videoEntry->getVideoId();
+
+        } catch (Zend_Gdata_App_Exception $e) {
+            $exceptionCaught = true;
+        }
+
+        $this->assertTrue($exceptionCaught, 'Expected exception not caught: ' .
+            'Zend_Gdata_AppException');
+    }
+
+    public function testGetVersionExceptionOnGetRacy() {
+        $videoEntry = new Zend_Gdata_YouTube_VideoEntry();
+        $videoEntry->setMajorProtocolVersion(2);
+
+        $exceptionCaught = false;
+
+        try {
+            $videoEntry->getRacy();
+        } catch (Zend_Gdata_App_VersionException $e) {
+            $exceptionCaught = true;
+        }
+
+        $this->assertTrue($exceptionCaught, 'Expected exception not caught: ' .
+            'Zend_Gdata_App_VersionException');
+    }
+
+    public function testGetVersionExceptionOnSetRacy() {
+        $videoEntry = new Zend_Gdata_YouTube_VideoEntry();
+        $videoEntry->setMajorProtocolVersion(2);
+
+        $exceptionCaught = false;
+
+        try {
+            $videoEntry->getRacy();
+        } catch (Zend_Gdata_App_VersionException $e) {
+            $exceptionCaught = true;
+        }
+
+        $this->assertTrue($exceptionCaught, 'Expected exception not caught: ' .
+            'Zend_Gdata_App_VersionException');
     }
 
     public function testEmptyEntryShouldHaveNoExtensionElements() {
@@ -273,6 +424,18 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(count($this->entry->extensionAttributes) == 0);
     }
 
+    public function testSampleEntryShouldHaveNoExtensionElementsV2() {
+        $this->entry->transferFromXML($this->v2EntryText);
+        $this->assertTrue(is_array($this->entry->extensionElements));
+        $this->assertTrue(count($this->entry->extensionElements) == 0);
+    }
+
+    public function testSampleEntryShouldHaveNoExtensionAttributesV2() {
+        $this->entry->transferFromXML($this->v2EntryText);
+        $this->assertTrue(is_array($this->entry->extensionAttributes));
+        $this->assertTrue(count($this->entry->extensionAttributes) == 0);
+    }
+
     public function testEmptyVideoEntryToAndFromStringShouldMatch() {
         $entryXml = $this->entry->saveXML();
         $newVideoEntry = new Zend_Gdata_YouTube_VideoEntry();
@@ -291,6 +454,12 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->verifyAllPrivateSamplePropertiesAreCorrect($this->entry);
     }
 
+    public function testV2SamplePropertiesAreCorrect() {
+        $this->entry->transferFromXML($this->v2EntryText);
+        $this->entry->setMajorProtocolVersion(2);
+        $this->verifyAllV2SamplePropertiesAreCorrect($this->entry);
+    }
+
     public function testGetVideoTitle() {
         $this->entry->transferFromXML($this->entryText);
         $videoEntry = $this->entry;
@@ -337,8 +506,10 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
     public function testGetVideoThumbnails() {
         $this->entry->transferFromXML($this->entryText);
         $videoEntry = $this->entry;
+
         $mediaThumbnails1 = $videoEntry->getMediaGroup()->getThumbnail();
         $mediaThumbnails2 = $videoEntry->getVideoThumbnails();
+
         $this->assertEquals(count($mediaThumbnails1), count($mediaThumbnails2));
 
         $foundThumbnail = false;
@@ -365,7 +536,7 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $keywordsString = (string) $keywords;
 
         if (strlen(trim($keywordsString)) > 0) {
-            $keywordArray = split('(, *)|,', $keywordsString);
+            $keywordArray = preg_split('/(, *)|,/', $keywordsString);
         }
 
         $tagArray = $videoEntry->getVideoTags();
@@ -390,7 +561,7 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $videoEntry->setVideoTags($newKeywordsString);
 
         if (strlen(trim($newKeywordsString)) > 0) {
-            $keywordArray = split('(, *)|,', $newKeywordsString);
+            $keywordArray = preg_split('/(, *)|,/', $newKeywordsString);
         }
 
         $tagArray = $videoEntry->getVideoTags();
@@ -544,7 +715,7 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('rejected', $videoState->getName());
         $this->assertEquals('inappropriate', $videoState->getReasonCode());
         $this->assertEquals('http://www.youtube.com/t/community_guidelines', $videoState->getHelpUrl());
-        $this->assertEquals('The content of this video may violate the terms of use.', 
+        $this->assertEquals('The content of this video may violate the terms of use.',
                             $videoState->getText());
     }
 
@@ -571,4 +742,26 @@ class Zend_Gdata_YouTube_VideoEntryTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($videoEntry->isVideoPrivate());
     }
 
+    public function testRetrieveCommentsFeedUrl() {
+        $this->entry->transferFromXML($this->entryText);
+        $commentsFeedUrl = $this->entry->getVideoCommentFeedUrl();
+        $this->assertEquals($commentsFeedUrl,
+            'http://gdata.youtube.com/feeds/videos/UMFI1hdm96E/comments');
+    }
+
+    public function testAddVideoEntryRating()
+    {
+        $this->entry->transferFromXML($this->entryText);
+        $ratingValue = 2;
+        $entryWithRating = $this->entry->setVideoRating($ratingValue);
+        $this->assertTrue(
+            $entryWithRating instanceof Zend_Gdata_YouTube_VideoEntry);
+
+        $rating = $entryWithRating->getRating();
+        $this->assertTrue(
+            $rating instanceof Zend_Gdata_Extension_Rating);
+
+        $this->assertEquals($rating->getValue(), $ratingValue);
+    }
+
 }
