@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ValidateTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * @see Zend_Validate
  */
@@ -37,13 +30,18 @@ require_once 'Zend/Validate.php';
  */
 require_once 'Zend/Validate/Abstract.php';
 
+/**
+ * @see Zend_Translate
+ */
+require_once 'Zend/Translate.php';
 
 /**
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Validate
  */
 class Zend_ValidateTest extends PHPUnit_Framework_TestCase
 {
@@ -64,6 +62,16 @@ class Zend_ValidateTest extends PHPUnit_Framework_TestCase
         $this->_validator = new Zend_Validate();
     }
 
+    /**
+     * Resets the default namespaces
+     *
+     * @return void
+     */
+    public function tearDown()
+    {
+        Zend_Validate::setDefaultNamespaces(array());
+    }
+
     /**
      * Ensures expected results from empty validator chain
      *
@@ -132,26 +140,112 @@ class Zend_ValidateTest extends PHPUnit_Framework_TestCase
      */
     public function testStaticFactoryWithConstructorArguments()
     {
-        $this->assertTrue(Zend_Validate::is('12', 'Between', array(1, 12)));
-        $this->assertFalse(Zend_Validate::is('24', 'Between', array(1, 12)));
+        $this->assertTrue(Zend_Validate::is('12', 'Between', array('min' => 1, 'max' => 12)));
+        $this->assertFalse(Zend_Validate::is('24', 'Between', array('min' => 1, 'max' => 12)));
     }
 
     /**
      * Ensures that if we specify a validator class basename that doesn't
      * exist in the namespace, is() throws an exception.
+     *
+     * Refactored to conform with ZF-2724.
+     *
+     * @group  ZF-2724
+     * @return void
+     * @expectedException Zend_Validate_Exception
      */
     public function testStaticFactoryClassNotFound()
     {
-        try {
-            $this->assertTrue(Zend_Validate::is('1234', 'UnknownValidator'));
-            $this->fail('Expected to catch Zend_Validate_Exception');
-        } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Validate_Exception', $e,
-                'Expected exception of type Zend_Validate_Exception, got '.get_class($e));
-            $this->assertEquals("Validate class not found from basename 'UnknownValidator'", $e->getMessage());
+        Zend_Validate::is('1234', 'UnknownValidator');
+    }
+
+    /**
+     * Testing Namespaces
+     *
+     * @return void
+     */
+    public function testNamespaces()
+    {
+        $this->assertEquals(array(), Zend_Validate::getDefaultNamespaces());
+        $this->assertFalse(Zend_Validate::hasDefaultNamespaces());
+
+        Zend_Validate::setDefaultNamespaces('TestDir');
+        $this->assertEquals(array('TestDir'), Zend_Validate::getDefaultNamespaces());
+
+        Zend_Validate::setDefaultNamespaces('OtherTestDir');
+        $this->assertEquals(array('OtherTestDir'), Zend_Validate::getDefaultNamespaces());
+
+        $this->assertTrue(Zend_Validate::hasDefaultNamespaces());
+
+        Zend_Validate::setDefaultNamespaces(array());
+
+        $this->assertEquals(array(), Zend_Validate::getDefaultNamespaces());
+        $this->assertFalse(Zend_Validate::hasDefaultNamespaces());
+
+        Zend_Validate::addDefaultNamespaces(array('One', 'Two'));
+        $this->assertEquals(array('One', 'Two'), Zend_Validate::getDefaultNamespaces());
+
+        Zend_Validate::addDefaultNamespaces('Three');
+        $this->assertEquals(array('One', 'Two', 'Three'), Zend_Validate::getDefaultNamespaces());
+
+        Zend_Validate::setDefaultNamespaces(array());
+    }
+
+    public function testIsValidWithParameters()
+    {
+        $this->assertTrue(Zend_Validate::is(5, 'Between', array(1, 10)));
+        $this->assertTrue(Zend_Validate::is(5, 'Between', array('min' => 1, 'max' => 10)));
+    }
+
+    public function testSetGetMessageLengthLimitation()
+    {
+        Zend_Validate::setMessageLength(5);
+        $this->assertEquals(5, Zend_Validate::getMessageLength());
+
+        $valid = new Zend_Validate_Between(1, 10);
+        $this->assertFalse($valid->isValid(24));
+        $message = current($valid->getMessages());
+        $this->assertTrue(strlen($message) <= 5);
+    }
+
+    public function testSetGetDefaultTranslator()
+    {
+        set_error_handler(array($this, 'errorHandlerIgnore'));
+        $translator = new Zend_Translate('array', array(), 'en');
+        restore_error_handler();
+        Zend_Validate_Abstract::setDefaultTranslator($translator);
+        $this->assertSame($translator->getAdapter(), Zend_Validate_Abstract::getDefaultTranslator());
+    }
+
+    /**
+     * Handle file not found errors
+     *
+     * @group  ZF-2724
+     * @param  int $errnum
+     * @param  string $errstr
+     * @return void
+     */
+    public function handleNotFoundError($errnum, $errstr)
+    {
+        if (strstr($errstr, 'No such file')) {
+            $this->error = true;
         }
     }
 
+    /**
+     * Ignores a raised PHP error when in effect, but throws a flag to indicate an error occurred
+     *
+     * @param  integer $errno
+     * @param  string  $errstr
+     * @param  string  $errfile
+     * @param  integer $errline
+     * @param  array   $errcontext
+     * @return void
+     */
+    public function errorHandlerIgnore($errno, $errstr, $errfile, $errline, array $errcontext)
+    {
+        $this->_errorOccurred = true;
+    }
 }
 
 
